1.0.0a1 (2020-02-25)
####################

Initial functionality:

- Start/stop recordings
- Start/stop calibrations
- Request version
- Estimate clock offsets
- Send messages/notifications/annotations
- Start plugins
